#! /usr/bin/python

# Import the base UI toolkit modules
from gi.repository import Gdk    
from gi.repository import Gtk

from gi.repository import Dee
# FIXME: Some weird bug in Dee or PyGI makes Dee fail unless we probe
#        it *before* we import the Unity module... ?!
_m = dir(Dee.SequenceModel)

# Import the module for sending indications to the Message Menu
from gi.repository import Indicate

# Import our base module to access icon paths
import hello_unity


class HelloMessageMenu(hello_unity.HelloUnitySection):

    def __init__(self):

        self.indicate_server = Indicate.Server.ref_default()
        self.indicate_server.set_type("message")
        self.indicate_server.set_desktop_file("/usr/share/applications/hello-unity.desktop")
        self.indicate_server.show()

        self.indicators = list()

    def get_controls(self):
        '''
        Creates and returns a Gtk widgets containing the controls for this
        section of Hello Unity
        '''

        # Use a GtkTable to layout the controls
        controls = Gtk.Table(4, 2, False)

        self.indicate_label = Gtk.Entry()
        self.indicate_label.set_text("New Hello")
        
        controls.attach(Gtk.Label("Label"), 0, 1, 0, 1)
        controls.attach(self.indicate_label, 1, 2, 0, 1, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL)

        self.indicate_count = Gtk.SpinButton()
        self.indicate_count.set_increments(1, 1)
        self.indicate_count.set_range(0, 999)

        controls.attach(Gtk.Label("Count"), 0, 1, 1, 2)
        controls.attach(self.indicate_count, 1, 2, 1, 2, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL)

        self.draw_attention = Gtk.CheckButton.new_with_label('Set Menu Attention')
        controls.attach(self.draw_attention, 1, 2, 2, 3, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL)

        self.new_button = Gtk.Button("Add Indication")
        self.new_button.connect('clicked', self.add_indication)
        
        controls.attach(self.new_button, 1, 2, 3, 4, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL)
        return controls

    def add_indication(self, button):
        indication = Indicate.Indicator.new_with_server(self.indicate_server)
        indication.set_property("subtype", "im")
        indication.set_property("sender", self.indicate_label.get_text())

        indication.set_property("count", str(int(self.indicate_count.get_value())))
        if self.draw_attention.get_active():
            indication.set_property("draw-attention", "true")
        else:
            indication.set_property("draw-attention", "false")

        indication.connect("user-display", self.remove_indication)
        indication.show()
        self.indicators.append(indication)

    def remove_indication(self, indication, timestamp):
        indication.set_displayed(True)
        self.indicate_server.remove_indicator(indication)
        self.indicators.remove(indication)
        
    def get_code(self):
        '''
        Gets the code for this section to display in Hello Unity.

        In this case, it will  just read this file's contents
        '''
        
        codefilename = __file__
        if codefilename.endswith('.pyc'):
            codefilename = codefilename[:-1]
        codefile = open(codefilename)
        code = codefile.read()
        codefile.close()
        return code
