#! /usr/bin/python

from gi.repository import Gdk    
from gi.repository import Gtk
from gi.repository import GtkSource

import hello_unity
from .indicator import HelloIndicator
from .launcher import HelloLauncher
from .messagemenu import HelloMessageMenu
from .notifications import HelloNotifications

class HelloWindow(Gtk.Window):

    def __init__(self):
        Gtk.Window.__init__(self, title="Hello Unity")

        self.set_default_size(500, 500)
        self.color_icon = Gtk.Image.new_from_file('/usr/share/pixmaps/%s.svg' % hello_unity.COLOR_ICON_PATH)

        self.set_icon(self.color_icon.get_pixbuf())

        self.content = Gtk.VBox()

        self.header = Gtk.HBox()
        self.header.pack_start(Gtk.Image.new_from_pixbuf(self.color_icon.get_pixbuf().scale_simple(64, 64,  0)), False, False, 10)
        intro = Gtk.Label()
        intro.set_markup('''
<b>Hello Unity!</b>

This is a showcase of the different ways an
application can integrate with Ubuntu Unity.

<a href="http://developer.ubuntu.com/resources/technologies/unity/">View the Documentation</a>
''')
        self.header.pack_end(intro, True, True, 10)

        self.content.pack_start(self.header, False, False, 10)

        self.sections = Gtk.Notebook()

        self.add_section("Launcher", HelloLauncher())
        self.add_section("Indicator", HelloIndicator())
        self.add_section("Message Menu", HelloMessageMenu())
        #self.add_section("Sound Menu", hello_unity.HelloUnitySection())
        #self.add_section("Dash", hello_unity.HelloUnitySection())
        self.add_section("Notifications", HelloNotifications())

        self.content.add(self.sections)

        self.add(self.content)

    def add_section(self, name, section):
        box = Gtk.Box.new(Gtk.Orientation.VERTICAL, 5)
        box.pack_start(section.get_controls(), False, False, 0)

        scrolledwindow = Gtk.ScrolledWindow()
        scrolledwindow.set_hexpand(True)
        scrolledwindow.set_vexpand(True)
        scrolledwindow.set_min_content_height(50)

        lm = GtkSource.LanguageManager()
        codebuffer = GtkSource.Buffer.new_with_language(lm.get_language('python'))
        codebuffer.set_highlight_syntax(True)
        code = GtkSource.View.new_with_buffer(codebuffer)
        code.mime_lang = 'text/x-python'
        #code.set_lang(code.mime_lang)
        code.set_show_line_numbers(True)
        code.set_editable(False)
        code.get_buffer().set_text(section.get_code())

        scrolledwindow.add(code)
        box.add(scrolledwindow)
        self.sections.append_page(box, Gtk.Label(name))
